==> haskell-pointed-5.0.1-106-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pointed
version: 5.0.1
id: pointed-5.0.1-HgaRs9vRF6i9YNfUynJ9oe
key: pointed-5.0.1-HgaRs9vRF6i9YNfUynJ9oe
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/pointed/
synopsis: Pointed and copointed data
description:
    Pointed and copointed data.
category: Data
abi: e8b57fbfbd5e3e50b3b7fa0fdece242e
exposed: True
exposed-modules:
    Data.Copointed Data.Pointed
import-dirs: /usr/lib/ghc-8.6.5/site-local/pointed-5.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pointed-5.0.1
hs-libraries: HSpointed-5.0.1-HgaRs9vRF6i9YNfUynJ9oe
depends:
    base-4.12.0.0 comonad-5.0.5-CthxCPGmo5h60L0drN1HHd
    containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    kan-extensions-5.2-ITl9kH0KSU56u5NPvHaWSH
    semigroupoids-5.3.3-KFEReOTUWayAwY1pytSwUo stm-2.5.0.0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
haddock-interfaces: /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html: /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pointed-5.0.1-107-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pointed
version: 5.0.1
id: pointed-5.0.1-6RJBKXDjyLe3GdifEFcavr
key: pointed-5.0.1-6RJBKXDjyLe3GdifEFcavr
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/pointed/
synopsis: Pointed and copointed data
description:
    Pointed and copointed data.
category: Data
abi: 4de97fb3a4bc87df0ab86423ae04d33f
exposed: True
exposed-modules:
    Data.Copointed Data.Pointed
import-dirs: /usr/lib/ghc-8.6.5/site-local/pointed-5.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pointed-5.0.1
hs-libraries: HSpointed-5.0.1-6RJBKXDjyLe3GdifEFcavr
depends:
    base-4.12.0.0 comonad-5.0.5-4oKFRzjdJyn9LPwjAsvqPG
    containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    kan-extensions-5.2-CN96QmSegkqBDiTnuJhVG1
    semigroupoids-5.3.3-5c90p3ZZL5SEVl9HRh2nSh stm-2.5.0.0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
haddock-interfaces: /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html: /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
